@@ -1,7 +1,7 @@
-from concurrent.futures import ThreadPoolExecutor
 import time
 import io
-from .feature_column import FeatureColumn
+from .feature import Feature
+from concurrent.futures import ThreadPoolExecutor
 
 
 class FeatureGroupVersion():
@@ -9,7 +9,7 @@ class FeatureGroupVersion():
         A materialized version of a feature group
     '''
 
-    def __init__(self, client, featureGroupVersion=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, columns={}):
+    def __init__(self, client, featureGroupVersion=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, features={}):
         self.client = client
         self.id = featureGroupVersion
         self.feature_group_version = featureGroupVersion
@@ -18,16 +18,17 @@ class FeatureGroupVersion():
         self.created_at = createdAt
         self.status = status
         self.error = error
-        self.columns = client._build_class(FeatureColumn, columns)
+        self.deployable = deployable
+        self.features = client._build_class(Feature, features)
 
     def __repr__(self):
-        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)}, sql={repr(self.sql)}, source_tables={repr(self.source_tables)}, created_at={repr(self.created_at)}, status={repr(self.status)}, error={repr(self.error)}, columns={repr(self.columns)})"
+        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)}, sql={repr(self.sql)}, source_tables={repr(self.source_tables)}, created_at={repr(self.created_at)}, status={repr(self.status)}, error={repr(self.error)}, deployable={repr(self.deployable)}, features={repr(self.features)})"
 
     def __eq__(self, other):
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'feature_group_version': self.feature_group_version, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'columns': [elem.to_dict() for elem in self.columns or []]}
+        return {'feature_group_version': self.feature_group_version, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'features': self.features.to_dict() if self.features else None}
 
     def export_to_file_connector(self, location, export_file_format):
         return self.client.export_feature_group_version_to_file_connector(self.feature_group_version, location, export_file_format)
